openclean\_notebook.controller package
======================================

.. automodule:: openclean_notebook.controller
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 3

   openclean_notebook.controller.spreadsheet

Submodules
----------

.. toctree::
   :maxdepth: 3

   openclean_notebook.controller.comm
   openclean_notebook.controller.html
